@@ -1,5 +1,6 @@
+use super::mod_use;
 use super::parser;
-use parser::Token;
+use crate::lexer::Token;
 use std::ops::Range;
 
 // This trait will be useful later
@@ -7,16 +8,6 @@ pub trait HasSpan {
     fn span(&self) -> &Range<usize>;
 }
 
-#[macro_use]
-mod macros {
-    macro_rules! mod_use {
-        { $(use $mod:ident;)+ } => { $(
-                mod $mod;
-                pub use $mod::*;
-            )+ };
-    }
-}
-
 mod_use! {
     use script;
     use target;
